@@ -2,7 +2,7 @@
 # Copyright (c) Ezcad Development Team. All Rights Reserved.
 
 from ezcad.config.base import _
-from ezcad.widgets.list2table import list2table
+from gocube.info_table import list2table
 
 
 def dict_sidx_table(dict_sidx):
